@@ -14,8 +14,8 @@ class QtSassTheme:
     def __init__(self):
         # set the icons
         cur_dir = os.path.dirname(__file__)
-        ico_filename = os.path.join(cur_dir, 'ico/_icons.scss')
         icon_path = cur_dir.replace(os.path.sep, posixpath.sep)
+        ico_filename = os.path.join(icon_path, 'ico/_icons.scss').replace(os.path.sep, posixpath.sep)
         self.__setIcoPath(ico_filename, icon_path)
         self.__prepareFineLookingGUI()
 
@@ -72,6 +72,32 @@ class QtSassTheme:
         else:
             pass
 
+    def __setFontSize(self, var_filename, font_size):
+        font = QApplication.font()
+        family_name = QApplication.font().family()
+        font.setFamily(family_name)
+        font.setPointSize(font_size)
+        font.setStyleStrategy(QFont.PreferAntialias)
+        QApplication.setFont(font)
+
+        # with open(var_filename, 'r') as f:
+        #     lines = f.readlines()
+        #
+        # new_line_for_font_size = f'$fontsize: {font_size}pt;'
+        #
+        # idx_to_replace = 0
+        #
+        # for i, line in enumerate(lines):
+        #     if 'fontsize' in line:
+        #         idx_to_replace = i
+        #         break
+        #
+        # lines[idx_to_replace] = new_line_for_font_size
+        #
+        # with open(var_filename, 'w') as f:
+        #     f.writelines(lines)
+
+
     def __getStyle(self, filename):
         cur_dir = os.path.dirname(__file__)
         sass_dirname = os.path.join(cur_dir, 'sass')
@@ -80,7 +106,7 @@ class QtSassTheme:
         css = qtsass.compile_filename(os.path.join(sass_dirname, filename), temp_file)
         return css
 
-    def getThemeFiles(self, theme: str = 'dark_gray', background_darker=False, output_path=os.getcwd()):
+    def getThemeFiles(self, theme: str = 'dark_gray', font_size=9, background_darker=False, output_path=os.getcwd()):
         theme_lst = ['dark_gray', 'dark_blue', 'light_gray', 'light_blue']
         cur_dir = os.path.dirname(__file__)
         official_theme_flag = theme in theme_lst
@@ -140,6 +166,11 @@ class QtSassTheme:
         else:
             self.__setCustomThemeColor(var_filename, theme)
         self.__setBackgroundPolicy(var_filename, background_darker)
+        self.__setFontSize(var_filename, font_size)
+
+        # fade menu and tooltip
+        QApplication.setEffectEnabled(Qt.UI_FadeMenu, True)
+        QApplication.setEffectEnabled(Qt.UI_FadeTooltip, True)
 
     def setThemeFiles(self, main_window: QWidget, input_path='res', exclude_type_lst: list = []):
         if os.path.basename(os.getcwd()) != input_path:
@@ -213,25 +244,6 @@ class QtSassTheme:
                 menu_bar = main_window.menuBar()  # menu bar
                 menu_bar.setStyleSheet(menu_bar_style)
 
-        # modrenize the font - for pyqt5/pyside2
-        if os.environ['QT_API'] == 'pyqt5' or os.environ['QT_API'] == 'pyside2':
-            def modernizeAppFont():
-                from qtpy.QtWidgets import qApp
-                # modernize the font
-                appFont = qApp.font()
-                # font family: arial
-                appFont.setFamily('Arial')
-                # font size: 9~12
-                appFont.setPointSize(min(12, max(9, appFont.pointSize() * qApp.desktop().logicalDpiX() / 96.0)))
-                # font style strategy: antialiasing
-                appFont.setStyleStrategy(QFont.PreferAntialias)
-                qApp.setFont(appFont)
-                # fade menu and tooltip
-                qApp.setEffectEnabled(Qt.UI_FadeMenu, True)
-                qApp.setEffectEnabled(Qt.UI_FadeTooltip, True)
-
-            modernizeAppFont()
-
     def getThemeStyle(self):
         css = self.__getStyle('theme.scss')
         return css
